package cn.kk.spring_simple_operation;

import cn.kk.spring_simple_operation.entity.SyncProductPublish;
import cn.kk.spring_simple_operation.mapper.SyncProductPublishMapper;
import cn.kk.spring_simple_operation.mapper.VideoProductMapper;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

@SpringBootTest
class SpringSimpleOperationApplicationTests {

	private static final BigDecimal               TWENTY = new BigDecimal("20");
	private static final BigDecimal               FORTY  = new BigDecimal("40");
	@Resource
	private              SyncProductPublishMapper syncProductPublishMapper;

	@Resource
	private VideoProductMapper videoProductMapper;


	@Test
	void contextLoads() {
	}

	@Test
	void testSyncProductPublish() {
		//List<String> shortUrlSkuList = videoProductMapper.selectHaveTask();

		Map<String, Integer> salesMap = new HashMap<>();
		salesMap.put("<20", 0);
		salesMap.put("20~40", 0);
		salesMap.put(">40", 0);

		Set<String> haveSkuSet = new HashSet<>();

		// 母体sku
		List<SyncProductPublish> syncProductPublishes = syncProductPublishMapper.selectMotherSku();

		syncProductPublishes.forEach(item -> {
			List<SyncProductPublish> subList = syncProductPublishMapper.selectList(Wrappers.<SyncProductPublish>lambdaQuery().eq(SyncProductPublish::getParentAsin, item.getRelationKey()).select(SyncProductPublish::getSku, SyncProductPublish::getThirtyDaySales));
			subList.add(item);

			String s = checkPriceAndSales(subList, item.getLowestPrice());
			if (StringUtils.isBlank(s)) {
				return;
			}
			salesMap.put(s, salesMap.get(s) + 1);
			haveSkuSet.addAll(subList.stream().map(SyncProductPublish::getSku).collect(Collectors.toList()));

		});
		System.out.println(JSONObject.toJSONString(salesMap));


	}

	private String checkPriceAndSales(List<SyncProductPublish> subList, BigDecimal lowestPrice) {
		if (CollectionUtils.isEmpty(subList) || lowestPrice.compareTo(BigDecimal.ZERO) < 0) {
			return null;
		}
		int sum = subList.stream().map(SyncProductPublish::getThirtyDaySales).reduce(Integer::sum).get();
		if (lowestPrice.compareTo(TWENTY) <= 0 && sum >= 100) {
			return "<20";
		}
		else if (lowestPrice.compareTo(TWENTY) > 0 && lowestPrice.compareTo(FORTY) <= 0 && sum >= 80) {
			return "20~40";
		}
		else if (lowestPrice.compareTo(FORTY) > 0 && sum >= 50) {
			return ">40";
		}
		return null;
	}

}
